==> haskell-trifecta-1.6.2.1-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-trifecta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: trifecta
version: 1.6.2.1
id: trifecta-1.6.2.1-B5WV3kZiOBnIOaoG8Bjgia
key: trifecta-1.6.2.1-B5WV3kZiOBnIOaoG8Bjgia
license: BSD3
copyright: Copyright (C) 2010-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/trifecta/
synopsis: A modern parser combinator library with convenient diagnostics
description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics
category: Text, Parsing, Diagnostics, Pretty Printer, Logging
author: Edward A. Kmett
exposed: True
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Util.Array Text.Trifecta.Util.IntervalMap
    Text.Trifecta.Util.It
hidden-modules: Text.Trifecta.Instances
                Text.Trifecta.Util.Combinators
abi: ca1f4f9c14a906fd5fa0f560d5eca335
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/trifecta-1.6.2.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/trifecta-1.6.2.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/trifecta-1.6.2.1
hs-libraries: HStrifecta-1.6.2.1-B5WV3kZiOBnIOaoG8Bjgia
depends:
    ansi-terminal-0.6.2.3-AKTYR0nthhUCHW4HMZvJFX
    ansi-wl-pprint-0.6.7.3-BxXaXM4de7bF6SGXMvMtbC array-0.5.1.1
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    charset-0.3.7.1-IQIZy6NlCuI6iyAvJEMNq8
    comonad-5-FocVP0xchqoELxW0q31ZBF containers-0.5.7.1 deepseq-1.4.2.0
    fingertree-0.1.1.0-C6YFXKIQXOA6HvmvFT5gT9 ghc-prim-0.5.0.0
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    lens-4.15.1-DpGqRVzlC9SDatwSfQX36G mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    parsers-0.12.4-290D1jd2R5FaBho7dlJ4M
    profunctors-5.2-DDzWnW7PWEeEYRCGSjacrC
    reducers-3.12.1-2Swcb53ldVvD4253gH5RvN
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz transformers-0.5.2.0
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
haddock-interfaces: /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html: /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-trifecta-1.6.2.1-11-i686.pkg.tar.xz: usr/share/haskell/register/haskell-trifecta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: trifecta
version: 1.6.2.1
id: trifecta-1.6.2.1-1GTkwGfIWrlSaEuH2SFBx
key: trifecta-1.6.2.1-1GTkwGfIWrlSaEuH2SFBx
license: BSD3
copyright: Copyright (C) 2010-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/trifecta/
synopsis: A modern parser combinator library with convenient diagnostics
description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics
category: Text, Parsing, Diagnostics, Pretty Printer, Logging
author: Edward A. Kmett
exposed: True
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Util.Array Text.Trifecta.Util.IntervalMap
    Text.Trifecta.Util.It
hidden-modules: Text.Trifecta.Instances
                Text.Trifecta.Util.Combinators
abi: 71713f6e3efa46c97d650511bb7ade38
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/trifecta-1.6.2.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/trifecta-1.6.2.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/trifecta-1.6.2.1
hs-libraries: HStrifecta-1.6.2.1-1GTkwGfIWrlSaEuH2SFBx
depends:
    ansi-terminal-0.6.2.3-AKTYR0nthhUCHW4HMZvJFX
    ansi-wl-pprint-0.6.7.3-BxXaXM4de7bF6SGXMvMtbC array-0.5.1.1
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    charset-0.3.7.1-64bxKwiao61GYFk7cH2T5U
    comonad-5-BXS82knsrtd4kXV7rg0uf7 containers-0.5.7.1 deepseq-1.4.2.0
    fingertree-0.1.1.0-C6YFXKIQXOA6HvmvFT5gT9 ghc-prim-0.5.0.0
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    lens-4.15.1-CuRlLuSK8hPFVcyNUy4IyC mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    parsers-0.12.4-9TuAHJrDdtVLctSD9PovNx
    profunctors-5.2-4zjFZFPovmkGmxhqVQbvW7
    reducers-3.12.1-92kTyD59m9rzRNoYBY6a0
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz transformers-0.5.2.0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
haddock-interfaces: /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html: /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
